@@ -22,7 +22,7 @@
 //
 //  =================================================================
 //
-//    16.05.14   <--  Date of Last Modification.
+//    23.12.15   <--  Date of Last Modification.
 //                   ~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 //  -----------------------------------------------------------------
 //
@@ -40,7 +40,7 @@
 //             mmdb::HetRec         ( HET    records                  )
 //             mmdb::Chain          ( chain class                     )
 //
-//  Copyright (C) E. Krissinel 2000-2013
+//  Copyright (C) E. Krissinel 2000-2015
 //
 //  =================================================================
 //
@@ -52,6 +52,7 @@
 #include "mmdb_model.h"
 #include "mmdb_manager.h"
 #include "mmdb_cifdefs.h"
+#include "mmdb_tables.h"
 
 namespace mmdb  {
 
@@ -1460,9 +1461,9 @@ namespace mmdb  {
 
 
   PResidue Chain::GetResidueCreate ( const ResName resName,
-                                      int           seqNum,
-                                      const InsCode insCode,
-                                      bool          Enforce )  {
+                                     int           seqNum,
+                                     const InsCode insCode,
+                                     bool          Enforce )  {
   //   Returns pointer on residue, whose name, sequence number and
   // insert code are given in resName, seqNum and insCode, respectively.
   // If such a residue is absent in the chain, one is created at
@@ -1477,8 +1478,13 @@ namespace mmdb  {
               (!strcmp(insCode,residue[i]->insCode)))  {
             if (!strcmp(resName,residue[i]->name))
               return residue[i]; // it is there; just return the pointer
-            else if (!Enforce)
+            else if (!Enforce)  {
+//            printf ( "1. sno=%i:%i, ic=[%s]:[%s] name=[%s]:[%s]\n",
+//                     seqNum,residue[i]->seqNum,
+//                     insCode,residue[i]->insCode,
+//                     resName,residue[i]->name );
               return NULL;       // duplicate seqNum and insCode!
+            }
           }
         }
     } else  {
@@ -1488,8 +1494,13 @@ namespace mmdb  {
               (!residue[i]->insCode[0]))  {
             if (!strcmp(resName,residue[i]->name))
               return residue[i]; // it is there; just return the pointer
-            else if (!Enforce)
+            else if (!Enforce)  {
+//            printf ( "2. sno=%i:%i, ic=[%s]:[%s] name=[%s]:[%s]\n",
+//                     seqNum,residue[i]->seqNum,
+//                     insCode,residue[i]->insCode,
+//                     resName,residue[i]->name );
               return NULL;       // duplicate seqNum and insCode!
+            }
           }
         }
     }
@@ -1611,6 +1622,25 @@ namespace mmdb  {
   }
 
 
+  void Chain::GetCoordSequence ( pstr & seq )  {
+  //   GetCoorSequence(...) returns sequence inferred from list
+  // of residues (which may differ from one in the file header).
+  // The sequence is returned as a null-terminated string 'seq'.
+  // On input, 'seq' should be either NULL or allocated (in which
+  // case the original allocation will be released).
+  int i,j;
+
+    if (seq) delete[] seq;
+    seq = new char[nResidues+1];
+
+    j = 0;
+    for (i=0;i<nResidues;i++)
+      if (residue[i])
+        Get1LetterCode ( residue[i]->GetResName(),seq[j++] );
+    seq[j] = char(0);
+
+  }
+
 
   //  ------------------  Deleting residues  --------------------------
 
