@@ -4,7 +4,7 @@
 //   CCP4 Coordinate Library: support of coordinate-related
 //   functionality in protein crystallography applications.
 //
-//   Copyright (C) Eugene Krissinel 2000-2008.
+//   Copyright (C) Eugene Krissinel 2000-2022.
 //
 //    This library is free software: you can redistribute it and/or
 //    modify it under the terms of the GNU Lesser General Public
@@ -22,7 +22,7 @@
 //
 //  =================================================================
 //
-//    24.04.03   <--  Date of Last Modification.
+//    09.02.22   <--  Date of Last Modification.
 //                   ~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 //  -----------------------------------------------------------------
 //
@@ -33,7 +33,7 @@
 //  **** Classes :
 //       ~~~~~~~~~
 //
-//  (C) E. Krissinel 2000-2008
+//  (C) E. Krissinel 2000-2022
 //
 //  =================================================================
 //
@@ -76,13 +76,13 @@ pstr makeString ( pstr S, int SLen, pstr FS, int FSLen )  {
 FORTRAN_SUBR ( MMDB_FCIF_CREATE, mmdb_fcif_create,
                (    // lengths-at-end list
                 fpstr DataName,     // file name
-                int   DataName_len  // fortran-hidden length of DataName
+                fpstr_size_t   DataName_len  // fortran-hidden length of DataName
                ), ( // lengths-in-structure list
                 fpstr DataName
                ), ( // lengths-follow list
-                fpstr DataName, int DataName_len
+                fpstr DataName, fpstr_size_t DataName_len
                ) )  {
-char S[500];
+char S[4096];
 
   if (mmCIFData)  delete mmCIFData;
   mmCIFData = new mmcif::Data ( makeString(S,sizeof(S),
@@ -100,11 +100,11 @@ FORTRAN_SUBR ( MMDB_FCIF_WRITE, mmdb_fcif_write,
                (    // lengths-at-end list
                 fpstr FileName,     // file name
                 int * iRet,         // return code
-                int   FileName_len  // fortran-hidden length of FileName
+                fpstr_size_t   FileName_len  // fortran-hidden length of FileName
                ), ( // lengths-in-structure list
     fpstr FileName, int *iRet
                ), ( // lengths-follow list
-    fpstr FileName, int FileName_len, int * iRet
+    fpstr FileName, fpstr_size_t FileName_len, int * iRet
                ) )  {
 pstr S;
 
@@ -134,13 +134,13 @@ FORTRAN_SUBR ( MMDB_FCIF_PUTDATE, mmdb_fcif_putdate,
                 fpstr CatName,     // category name
                 fpstr Tag,         // tag
                 int * iRet,        // return code
-                int   CatName_len, // fortran-hidden length of CatName
-                int   Tag_len      // fortran-hidden length of Tag
+                fpstr_size_t   CatName_len, // fortran-hidden length of CatName
+                fpstr_size_t   Tag_len      // fortran-hidden length of Tag
                ), ( // lengths-in-structure list
                 fpstr CatName, fpstr Tag, int * iRet
                ), ( // lengths-follow list
-                fpstr CatName, int CatName_len,
-                fpstr Tag,     int Tag_len,
+                fpstr CatName, fpstr_size_t CatName_len,
+                fpstr Tag,     fpstr_size_t Tag_len,
                 int * iRet
                ) )  {
 char CN[200],TN[200];
@@ -165,13 +165,13 @@ FORTRAN_SUBR ( MMDB_FCIF_PUTDOT, mmdb_fcif_putdot,
                 fpstr CatName,     // category name
                 fpstr Tag,         // tag
                 int * iRet,        // return code
-                int   CatName_len, // fortran-hidden length of CatName
-                int   Tag_len      // fortran-hidden length of Tag
+                fpstr_size_t   CatName_len, // fortran-hidden length of CatName
+                fpstr_size_t   Tag_len      // fortran-hidden length of Tag
                ), ( // lengths-in-structure list
                 fpstr CatName, fpstr Tag, int * iRet
                ), ( // lengths-follow list
-                fpstr CatName, int CatName_len,
-                fpstr Tag,     int Tag_len,
+                fpstr CatName, fpstr_size_t CatName_len,
+                fpstr Tag,     fpstr_size_t Tag_len,
                 int * iRet
                ) )  {
 char CN[200],TN[200];
@@ -197,13 +197,13 @@ FORTRAN_SUBR ( MMDB_FCIF_PUTQUESTION, mmdb_fcif_putquestion,
                 fpstr CatName,     // category name
                 fpstr Tag,         // tag
                 int * iRet,        // return code
-                int   CatName_len, // fortran-hidden length of CatName
-                int   Tag_len      // fortran-hidden length of Tag
+                fpstr_size_t   CatName_len, // fortran-hidden length of CatName
+                fpstr_size_t   Tag_len      // fortran-hidden length of Tag
                ), ( // lengths-in-structure list
                 fpstr CatName, fpstr Tag, int * iRet
                ), ( // lengths-follow list
-                fpstr CatName, int CatName_len,
-                fpstr Tag,     int Tag_len,
+                fpstr CatName, fpstr_size_t CatName_len,
+                fpstr Tag,     fpstr_size_t Tag_len,
                 int * iRet
                ) )  {
 char CN[200],TN[200];
@@ -232,15 +232,15 @@ FORTRAN_SUBR ( MMDB_FCIF_PUTSTRING, mmdb_fcif_putstring,
                 fpstr CatName,     // category name
                 fpstr Tag,         // tag
                 int * iRet,        // return code
-                int   Data_len,    // fortran-hidden length of Data
-                int   CatName_len, // fortran-hidden length of CatName
-                int   Tag_len      // fortran-hidden length of Tag
+                fpstr_size_t   Data_len,    // fortran-hidden length of Data
+                fpstr_size_t   CatName_len, // fortran-hidden length of CatName
+                fpstr_size_t   Tag_len      // fortran-hidden length of Tag
                ), ( // lengths-in-structure list
                 fpstr Data, fpstr CatName, fpstr Tag, int * iRet
                ), ( // lengths-follow list
-    fpstr Data,    int Data_len,
-                fpstr CatName, int CatName_len,
-                fpstr Tag,     int Tag_len,
+    fpstr Data,    fpstr_size_t Data_len,
+                fpstr CatName, fpstr_size_t CatName_len,
+                fpstr Tag,     fpstr_size_t Tag_len,
                 int * iRet
                ) )  {
 char CN[200],TN[200];
@@ -273,14 +273,14 @@ FORTRAN_SUBR ( MMDB_FCIF_PUTREAL, mmdb_fcif_putreal,
                 fpstr CatName,     // category name
                 fpstr Tag,         // tag
                 int * iRet,        // return code
-                int   CatName_len, // fortran-hidden length of CatName
-                int   Tag_len      // fortran-hidden length of Tag
+                fpstr_size_t   CatName_len, // fortran-hidden length of CatName
+                fpstr_size_t   Tag_len      // fortran-hidden length of Tag
                ), ( // lengths-in-structure list
                 apireal * V, fpstr CatName, fpstr Tag, int * iRet
                ), ( // lengths-follow list
     apireal * V,
-                fpstr CatName, int CatName_len,
-                fpstr Tag,     int Tag_len,
+                fpstr CatName, fpstr_size_t CatName_len,
+                fpstr Tag,     fpstr_size_t Tag_len,
                 int * iRet
                ) )  {
 char CN[200],TN[200];
@@ -307,14 +307,14 @@ FORTRAN_SUBR ( MMDB_FCIF_PUTINTEGER, mmdb_fcif_putinteger,
                 fpstr CatName,     // category name
                 fpstr Tag,         // tag
                 int * iRet,        // return code
-                int   CatName_len, // fortran-hidden length of CatName
-                int   Tag_len      // fortran-hidden length of Tag
+                fpstr_size_t   CatName_len, // fortran-hidden length of CatName
+                fpstr_size_t   Tag_len      // fortran-hidden length of Tag
                ), ( // lengths-in-structure list
                 int * I, fpstr CatName, fpstr Tag, int * iRet
                ), ( // lengths-follow list
     int * I,
-                fpstr CatName, int CatName_len,
-                fpstr Tag,     int Tag_len,
+                fpstr CatName, fpstr_size_t CatName_len,
+                fpstr Tag,     fpstr_size_t Tag_len,
                 int * iRet
                ) )  {
 char CN[200],TN[200];
@@ -340,13 +340,13 @@ FORTRAN_SUBR ( MMDB_FCIF_PUTLOOPDOT, mmdb_fcif_putloopdot,
                 fpstr Tag,         // tag
                 int * nrow,        // row number
                 int * iRet,        // return code
-                int   CatName_len, // fortran-hidden length of CatName
-                int   Tag_len      // fortran-hidden length of Tag
+                fpstr_size_t   CatName_len, // fortran-hidden length of CatName
+                fpstr_size_t   Tag_len      // fortran-hidden length of Tag
                ), ( // lengths-in-structure list
                 fpstr CatName, fpstr Tag, int * nrow, int * iRet
                ), ( // lengths-follow list
-                fpstr CatName, int CatName_len,
-                fpstr Tag,     int Tag_len,
+                fpstr CatName, fpstr_size_t CatName_len,
+                fpstr Tag,     fpsr_size_t Tag_len,
                 int * nrow,    int * iRet
                ) )  {
 char CN[200],TN[200];
@@ -375,13 +375,13 @@ FORTRAN_SUBR ( MMDB_FCIF_PUTLOOPQUESTION, mmdb_fcif_putloopquestion,
                 fpstr Tag,         // tag
                 int * nrow,        // row number
                 int * iRet,        // return code
-                int   CatName_len, // fortran-hidden length of CatName
-                int   Tag_len      // fortran-hidden length of Tag
+                fpstr_size_t   CatName_len, // fortran-hidden length of CatName
+                fpstr_size_t   Tag_len      // fortran-hidden length of Tag
                ), ( // lengths-in-structure list
                 fpstr CatName, fpstr Tag, int * nrow, int * iRet
                ), ( // lengths-follow list
-                fpstr CatName, int CatName_len,
-                fpstr Tag,     int Tag_len,
+                fpstr CatName, fpstr_size_t CatName_len,
+                fpstr Tag,     fpstr_size_t Tag_len,
                 int * nrow,    int * iRet
                ) )  {
 char CN[200],TN[200];
@@ -410,16 +410,16 @@ FORTRAN_SUBR ( MMDB_FCIF_PUTLOOPSTRING, mmdb_fcif_putloopstring,
                 fpstr Tag,         // tag
                 int * nrow,        // row number
                 int * iRet,        // return code
-                int   Data_len,    // fortran-hidden length of Data
-                int   CatName_len, // fortran-hidden length of CatName
-                int   Tag_len      // fortran-hidden length of Tag
+                fpstr_size_t   Data_len,    // fortran-hidden length of Data
+                fpstr_size_t   CatName_len, // fortran-hidden length of CatName
+                fpstr_size_t   Tag_len      // fortran-hidden length of Tag
                ), ( // lengths-in-structure list
                 fpstr Data, fpstr CatName, fpstr Tag,
                 int * nrow, int * iRet
                ), ( // lengths-follow list
-    fpstr Data,    int Data_len,
-                fpstr CatName, int CatName_len,
-                fpstr Tag,     int Tag_len,
+    fpstr Data,    fpstr_size_t Data_len,
+                fpstr CatName, fpstr_size_t CatName_len,
+                fpstr Tag,     fpstr_size_t Tag_len,
                 int * nrow,    int * iRet
                ) )  {
 char CN[200],TN[200];
@@ -454,15 +454,15 @@ FORTRAN_SUBR ( MMDB_FCIF_PUTLOOPREAL, mmdb_fcif_putloopreal,
                 fpstr Tag,         // tag
                 int * nrow,        // row number
                 int * iRet,        // return code
-                int   CatName_len, // fortran-hidden length of CatName
-                int   Tag_len      // fortran-hidden length of Tag
+                fpstr_size_t   CatName_len, // fortran-hidden length of CatName
+                fpstr_size_t   Tag_len      // fortran-hidden length of Tag
                ), ( // lengths-in-structure list
                 apireal * V, fpstr CatName, fpstr Tag,
                 int * nrow, int * iRet
                ), ( // lengths-follow list
     apireal * V,
-                fpstr CatName, int CatName_len,
-                fpstr Tag,     int Tag_len,
+                fpstr CatName, fpstr_size_t CatName_len,
+                fpstr Tag,     fpstr_size_t Tag_len,
                 int * nrow,    int * iRet
                ) )  {
 char CN[200],TN[200];
@@ -490,15 +490,15 @@ FORTRAN_SUBR ( MMDB_FCIF_PUTLOOPINTEGER, mmdb_fcif_putloopinteger,
                 fpstr Tag,         // tag
                 int * nrow,        // row number
                 int * iRet,        // return code
-                int   CatName_len, // fortran-hidden length of CatName
-                int   Tag_len      // fortran-hidden length of Tag
+                fpstr_size_t   CatName_len, // fortran-hidden length of CatName
+                fpstr_size_t   Tag_len      // fortran-hidden length of Tag
                ), ( // lengths-in-structure list
                 int * I, fpstr CatName, fpstr Tag,
                 int * nrow, int * iRet
                ), ( // lengths-follow list
     int * I,
-                fpstr CatName, int CatName_len,
-                fpstr Tag,     int Tag_len,
+                fpstr CatName, fpstr_size_t CatName_len,
+                fpstr Tag,     fpstr_size_t Tag_len,
                 int * nrow,    int * iRet
                ) )  {
 char CN[200],TN[200];
